#ifndef MATERIAL
#define MATERIAL

#include "GLShader.h"

struct Material {
	Material() = default;
	~Material() = default;
	Material(glm::vec3 albedo, GLfloat metallic, GLfloat roughness, GLfloat ao):
		Albedo(albedo), Metallic(metallic), Roughness(roughness), Ao(ao) { }

	float Ao = 0.1f;
	float Opacity = 1.0f;
	float Metallic = 0.4f;
	float Roughness = 0.2f;
	float Shininess = 1.0f;
	float Reflectivity = 0.0f;
	glm::vec3 Albedo = glm::vec3(0.6f);

	GLuint AoMap = 0;
	GLuint NormalMap = 0;
	GLuint AlbedoMap = 0;
	GLuint MetallicMap = 0;
	GLuint RoughnessMap = 0;
	GLuint SpecularBRDFMap = 0;

	void SetUniform(Shader& shader) {
		shader.bind();
		shader.setuniform("material.Ao", Ao);
		shader.setuniform("material.Albedo", Albedo);
		shader.setuniform("material.Metallic", Metallic);
		shader.setuniform("material.Roughness", Roughness);

		shader.setuniform("AoMap", AoMap, 0);
		shader.setuniform("AlbedoMap", AlbedoMap, 1);
		shader.setuniform("NormalMap", NormalMap, 2);
		shader.setuniform("MetallicMap", MetallicMap, 3);
		shader.setuniform("RoughnessMap", RoughnessMap, 4);
	}
};

#endif